@@ -60,7 +60,11 @@ mlappx.real <- function(val, grid, ...) {
 #  if(adjust!=0) {
 #    val <- val + (val - .Call(C_predmlip,grid,as.numeric(val)))*adjust
 #  }
-  vectorfun(function(x,threads=getOption('chebpol.threads')) .Call(C_evalmlip,grid,val,x,threads),
-            arity=length(grid), 
-            domain=lapply(grid,range))
+  vectorfun(function(x,threads=getOption('chebpol.threads'),
+                     blend=c('linear','cubic','sigmoid','parodic','square')) {
+    blend <- switch(match.arg(blend),linear=0L,sigmoid=1L,parodic=2L,cubic=3L,square=4L)
+    .Call(C_evalmlip,grid,val,x,threads,blend)
+  },
+  arity=length(grid), 
+  domain=lapply(grid,range))
 }
